varying vec4 v_fragmentColor;
varying vec2 v_texCoord;

uniform vec2 u_resolution;
uniform sampler2D u_texDOF;
uniform int u_depthMode; 
uniform int u_dofMode;

const float blurRadius = 4.0;
const float sampleNum = 2.0;

vec4 blur(vec2);

void main(void)
{
	vec4 sourceColor = texture2D(CC_Texture0, v_texCoord);
	vec4 blurColor = blur(v_texCoord);
	vec4 depthColor = texture2D(u_texDOF, v_texCoord);

	//float fDOF = smoothstep(0.1, 0.5, depthColor.r);
	
	vec4 resultColor = mix(sourceColor, blurColor, depthColor.r);
	resultColor.a = 1.0;

	if(0 < u_dofMode)
	{
		if(0 < u_depthMode)
			gl_FragColor = vec4(depthColor.r, depthColor.r, depthColor.r, 1.0);
		else
			gl_FragColor = resultColor;
	}
	else
	{
		gl_FragColor = sourceColor;
	}
}

vec4 blur(vec2 p)
{
    if (blurRadius > 0.0 && sampleNum > 1.0)
    {
        vec4 col = vec4(0);
        vec2 unit = 1.0 / u_resolution.xy;
        
        float r = blurRadius;
        float sampleStep = r / sampleNum;
        
        float count = 0.0;
        
        for(float x = -r; x < r; x += sampleStep)
        {
            for(float y = -r; y < r; y += sampleStep)
            {
                float weight = (r - abs(x)) * (r - abs(y));
                col += texture2D(CC_Texture0, p + vec2(x * unit.x, y * unit.y)) * weight;
                count += weight;
            }
        }
        
        return col / count;
    }
    
    return texture2D(CC_Texture0, p);
}