varying vec4 v_fragmentColor;
varying vec2 v_texCoord;

uniform vec2 v_resolution;
uniform sampler2D v_texDepth;

const float blurRadius = 10.0;
const float sampleNum = 5.0;

uniform int u_lightBloomMode;
uniform float u_blurRadius;
uniform float u_sampleNum;
uniform float u_intensity;

vec4 blur(vec2);

void main(void)
{
	vec4 sourceColor = texture2D(CC_Texture0, v_texCoord);
	vec4 lightColor = blur(v_texCoord) * u_intensity;
	lightColor.a = 1.0f;

	if(0 < u_lightBloomMode)
		gl_FragColor = sourceColor + lightColor;
	else
		gl_FragColor = sourceColor;

	// Depth Buffer Check 
	//vec4 depthColor = texture2D(v_texDepth, v_texCoord);
	//vec4 resultColor = vec4(depthColor.a, depthColor.a, depthColor.a, 1.0);
	//gl_FragColor = resultColor;

	//gl_FragColor = lightColor; // light bloom Ȯο
}

vec4 blur(vec2 p)
{
    if (u_blurRadius > 0.0 && u_sampleNum > 1.0)
    {
        vec4 col = vec4(0);
        vec2 unit = 1.0 / v_resolution.xy;
        
        float r = u_blurRadius;
        float sampleStep = r / u_sampleNum;
        
        float count = 0.0;
        
        for(float x = -r; x < r; x += sampleStep)
        {
            for(float y = -r; y < r; y += sampleStep)
            {
                float weight = (r - abs(x)) * (r - abs(y));
                col += texture2D(v_texDepth, p + vec2(x * unit.x, y * unit.y)) * weight;
                count += weight;
            }
        }
        
        return col / count;
    }
    
    return texture2D(v_texDepth, p);
}